@@ -1,14 +1,15 @@
-#!/usr/bin/env python
 # coding=utf-8
 
-from decimal import Decimal
 import binascii
 import codecs
-import time
+import re
 import requests
+import time
+
+from decimal import Decimal
 from ethereum.utils import sha3, ecsign, encode_int32
 
-from .exceptions import IdexWalletAddressNotFoundException, IdexPrivateKeyNotFoundException, IdexAPIException, IdexRequestException, IdexCurrencyNotFoundException
+from .exceptions import IdexException, IdexWalletAddressNotFoundException, IdexPrivateKeyNotFoundException, IdexAPIException, IdexRequestException, IdexCurrencyNotFoundException
 
 
 class Client(object):
@@ -164,10 +165,12 @@ class Client(object):
         :returns: nothing
 
         """
-        self._wallet_address = address
+        self._wallet_address = address.lower()
         nonce_res = self.get_my_next_nonce()
         self._start_nonce = nonce_res['nonce']
         if private_key:
+            if re.match(r"^0x[0-9a-zA-Z]{64}$", private_key) is None:
+                raise(IdexException("Private key in invalid format must satisfy 0x[0-9a-zA-Z]{64}"))
             self._private_key = private_key
 
     def get_wallet_address(self):
@@ -782,18 +785,22 @@ class Client(object):
 
         return res
 
-    def get_balances(self, address, complete=False):
+    def get_balances(self, token=None, complete=False):
         """Get available balances for an address (total deposited minus amount in open orders) indexed by token symbol.
 
         https://github.com/AuroraDAO/idex-api-docs#returnbalances
 
-        :param address: Address to query balances of
-        :type address: address string
+        :param token: The name or address of the token to get the balance for
+        :type token: string or hex string e.g 'EOS' or '0x7c5a0ce9267ed19b22f8cae653f198e3e8daf098'
         :param complete: Include available balances along with the amount you have in open orders for each token (Default False)
         :param complete: bool
 
         .. code:: python
 
+            # use token name
+            balances = client.get_balances('ETH')
+
+            # use token address
             balances = client.get_balances('0xca82b7b95604f70b3ff5c6ede797a28b11b47d63')
 
         :returns: API Response
@@ -822,8 +829,10 @@ class Client(object):
 
         """
 
+        currency = self.get_currency(token)
+
         data = {
-            'address': address
+            'address': currency['address']
         }
 
         path = 'returnBalances'
@@ -1387,7 +1396,6 @@ class Client(object):
         hash_data = [
             ['orderHash', order_hash, 'address'],
             ['nonce', self._get_nonce(), 'uint256'],
-            ['address', self._wallet_address, 'address'],
         ]
 
         json_data = {
